@@ -1,8 +1,6 @@
 /*
  * Channel extban type: matches users who are in a certain channel
  * -- jilles
- *
- * $Id: extb_channel.c 1723 2006-07-06 15:23:58Z jilles $
  */
 
 #include "stdinc.h"
@@ -12,11 +10,13 @@
 #include "hash.h"
 #include "ircd.h"
 
+static const char extb_desc[] = "Channel ($c) extban type";
+
 static int _modinit(void);
 static void _moddeinit(void);
 static int eb_channel(const char *data, struct Client *client_p, struct Channel *chptr, long mode_type);
 
-DECLARE_MODULE_AV1(extb_channel, _modinit, _moddeinit, NULL, NULL, NULL, "$Revision: 1723 $");
+DECLARE_MODULE_AV2(extb_channel, _modinit, _moddeinit, NULL, NULL, NULL, NULL, NULL, extb_desc);
 
 static int
 _modinit(void)
