@@ -1,8 +1,6 @@
 /*
  * Oper extban type: matches opers
  * -- jilles
- *
- * $Id: extb_oper.c 1299 2006-05-11 15:43:03Z jilles $
  */
 
 #include "stdinc.h"
@@ -12,11 +10,13 @@
 #include "s_newconf.h"
 #include "ircd.h"
 
+static const char extb_desc[] = "Oper ($o) extban type";
+
 static int _modinit(void);
 static void _moddeinit(void);
 static int eb_oper(const char *data, struct Client *client_p, struct Channel *chptr, long mode_type);
 
-DECLARE_MODULE_AV1(extb_oper, _modinit, _moddeinit, NULL, NULL, NULL, "$Revision: 1299 $");
+DECLARE_MODULE_AV2(extb_oper, _modinit, _moddeinit, NULL, NULL, NULL, NULL, NULL, extb_desc);
 
 static int
 _modinit(void)
