@@ -1,4 +1,4 @@
-/* 
+/*
  * Charybdis: an advanced ircd
  * ip_cloaking.c: provide user hostname cloaking
  *
@@ -17,6 +17,8 @@
 #include "s_serv.h"
 #include "numeric.h"
 
+static const char ip_cloaking_desc[] = "IP cloaking module that uses user mode +h";
+
 static int
 _modinit(void)
 {
@@ -43,8 +45,8 @@ mapi_hfn_list_av1 ip_cloaking_hfnlist[] = {
 	{ NULL, NULL }
 };
 
-DECLARE_MODULE_AV1(ip_cloaking, _modinit, _moddeinit, NULL, NULL,
-			ip_cloaking_hfnlist, "$Revision: 3526 $");
+DECLARE_MODULE_AV2(ip_cloaking, _modinit, _moddeinit, NULL, NULL,
+			ip_cloaking_hfnlist, NULL, NULL, ip_cloaking_desc);
 
 static void
 distribute_hostchange(struct Client *client_p, char *newhost)
@@ -88,7 +90,7 @@ do_host_cloak_ip(const char *inbuf, char *outbuf)
 	{
 		ipv6 = 1;
 
-		/* Damn you IPv6... 
+		/* Damn you IPv6...
 		 * We count the number of colons so we can calculate how much
 		 * of the host to cloak. This is because some hostmasks may not
 		 * have as many octets as we'd like.
@@ -103,7 +105,7 @@ do_host_cloak_ip(const char *inbuf, char *outbuf)
 	else if (!strchr(outbuf, '.'))
 		return;
 
-	for (tptr = outbuf; *tptr != '\0'; tptr++) 
+	for (tptr = outbuf; *tptr != '\0'; tptr++)
 	{
 		if (*tptr == ':' || *tptr == '.')
 		{
@@ -131,7 +133,7 @@ do_host_cloak_host(const char *inbuf, char *outbuf)
 
 	rb_strlcpy(outbuf, inbuf, HOSTLEN + 1);
 
-	/* pass 1: scramble first section of hostname using base26 
+	/* pass 1: scramble first section of hostname using base26
 	 * alphabet toasted against the FNV hash of the string.
 	 *
 	 * numbers are not changed at this time, only letters.
@@ -141,7 +143,7 @@ do_host_cloak_host(const char *inbuf, char *outbuf)
 		if (*tptr == '.')
 			break;
 
-		if (isdigit(*tptr) || *tptr == '-')
+		if (isdigit((unsigned char)*tptr) || *tptr == '-')
 			continue;
 
 		*tptr = b26_alphabet[(*tptr + accum) % 26];
@@ -153,11 +155,11 @@ do_host_cloak_host(const char *inbuf, char *outbuf)
 	/* pass 2: scramble each number in the address */
 	for (tptr = outbuf; *tptr != '\0'; tptr++)
 	{
-		if (isdigit(*tptr))
+		if (isdigit((unsigned char)*tptr))
 			*tptr = '0' + (*tptr + accum) % 10;
 
 		accum = (accum << 1) | (accum >> 31);
-	}	
+	}
 }
 
 static void
