@@ -2,8 +2,6 @@
  * Deny opers setting themselves +i unless they are bots (i.e. have
  * hidden_oper privilege).
  * -- jilles
- *
- * $Id: no_oper_invis.c 3219 2007-02-24 19:34:28Z jilles $
  */
 
 #include "stdinc.h"
@@ -15,6 +13,9 @@
 #include "s_conf.h"
 #include "s_newconf.h"
 
+static const char noi_desc[] =
+	"Disallow operators from setting user mode +i on themselves";
+
 static void h_noi_umode_changed(hook_data_umode_changed *);
 
 mapi_hfn_list_av1 noi_hfnlist[] = {
@@ -22,7 +23,7 @@ mapi_hfn_list_av1 noi_hfnlist[] = {
 	{ NULL, NULL }
 };
 
-DECLARE_MODULE_AV1(no_oper_invis, NULL, NULL, NULL, NULL, noi_hfnlist, "$Revision: 3219 $");
+DECLARE_MODULE_AV2(no_oper_invis, NULL, NULL, NULL, NULL, noi_hfnlist, NULL, NULL, noi_desc);
 
 static void
 h_noi_umode_changed(hook_data_umode_changed *hdata)
