@@ -1,7 +1,5 @@
 /*
  * Remote oper up notices.
- *
- * $Id: sno_globaloper.c 639 2006-01-29 21:42:06Z jilles $
  */
 
 #include "stdinc.h"
@@ -13,6 +11,9 @@
 #include "s_conf.h"
 #include "snomask.h"
 
+static const char sno_desc[] =
+	"Adds server notices for remote oper up";
+
 static void h_sgo_umode_changed(void *);
 
 mapi_hfn_list_av1 sgo_hfnlist[] = {
@@ -20,7 +21,7 @@ mapi_hfn_list_av1 sgo_hfnlist[] = {
 	{ NULL, NULL }
 };
 
-DECLARE_MODULE_AV1(sno_globaloper, NULL, NULL, NULL, NULL, sgo_hfnlist, "$Revision: 639 $");
+DECLARE_MODULE_AV2(sno_globaloper, NULL, NULL, NULL, NULL, sgo_hfnlist, NULL, NULL, sno_desc);
 
 static void
 h_sgo_umode_changed(void *vdata)
