@@ -4,8 +4,6 @@
  *
  * If #define OPERONLY is removed, then any user can use this snomask
  * (you need to put ~servnotice in oper_only_umodes for this to work).
- *
- * $Id: sno_whois.c 3498 2007-05-30 10:22:25Z jilles $
  */
 
 #include "stdinc.h"
@@ -18,6 +16,15 @@
 /* undefine this to allow anyone to receive whois notifications */
 #define OPERONLY
 
+static const char sno_desc[] =
+	"Adds server notice mask +W that allows "
+#ifdef OPERONLY
+	"operators"
+#else
+	"users"
+#endif
+	" to receive notices for when a WHOIS has been done on them";
+
 void show_whois(hook_data_client *);
 
 mapi_hfn_list_av1 whois_hfnlist[] = {
@@ -37,10 +44,10 @@ init(void)
 static void
 fini(void)
 {
-	snomask_modes['W'] = find_snomask_slot();
+	snomask_modes['W'] = 0;
 }
 
-DECLARE_MODULE_AV1(sno_whois, init, fini, NULL, NULL, whois_hfnlist, "$Revision: 3498 $");
+DECLARE_MODULE_AV2(sno_whois, init, fini, NULL, NULL, whois_hfnlist, NULL, NULL, sno_desc);
 
 void
 show_whois(hook_data_client *data)
@@ -48,7 +55,7 @@ show_whois(hook_data_client *data)
 	struct Client *source_p = data->client;
 	struct Client *target_p = data->target;
 
-	if(MyClient(target_p) && 
+	if(MyClient(target_p) &&
 #ifdef OPERONLY
 	   IsOper(target_p) &&
 #endif
