@@ -20,14 +20,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: restart.h 6 2005-09-10 01:02:21Z nenolod $
  */
 
 #ifndef INCLUDED_restart_h
 #define INCLUDED_restart_h
 
-void restart(const char *);
-void server_reboot(void);
+void restart(const char *) __attribute__((noreturn));
+void server_reboot(void) __attribute__((noreturn));
 
 #endif
