@@ -20,15 +20,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id$
  */
 
 #include "stdinc.h"
 #include "channel.h"
 #include "class.h"
 #include "client.h"
-#include "common.h"
 #include "match.h"
 #include "ircd.h"
 #include "hostmask.h"
@@ -46,30 +43,32 @@
 #include "bandbi.h"
 #include "operhash.h"
 
-static int mo_kline(struct Client *, struct Client *, int, const char **);
-static int ms_kline(struct Client *, struct Client *, int, const char **);
-static int me_kline(struct Client *, struct Client *, int, const char **);
-static int mo_unkline(struct Client *, struct Client *, int, const char **);
-static int ms_unkline(struct Client *, struct Client *, int, const char **);
-static int me_unkline(struct Client *, struct Client *, int, const char **);
+static const char kline_desc[] = "Provides the KLINE facility to ban users via hostmask";
+
+static void mo_kline(struct MsgBuf *, struct Client *, struct Client *, int, const char **);
+static void ms_kline(struct MsgBuf *, struct Client *, struct Client *, int, const char **);
+static void me_kline(struct MsgBuf *, struct Client *, struct Client *, int, const char **);
+static void mo_unkline(struct MsgBuf *, struct Client *, struct Client *, int, const char **);
+static void ms_unkline(struct MsgBuf *, struct Client *, struct Client *, int, const char **);
+static void me_unkline(struct MsgBuf *, struct Client *, struct Client *, int, const char **);
 
 struct Message kline_msgtab = {
-	"KLINE", 0, 0, 0, MFLG_SLOW,
+	"KLINE", 0, 0, 0, 0,
 	{mg_unreg, mg_not_oper, {ms_kline, 5}, {ms_kline, 5}, {me_kline, 5}, {mo_kline, 3}}
 };
 
 struct Message unkline_msgtab = {
-	"UNKLINE", 0, 0, 0, MFLG_SLOW,
+	"UNKLINE", 0, 0, 0, 0,
 	{mg_unreg, mg_not_oper, {ms_unkline, 4}, {ms_unkline, 4}, {me_unkline, 3}, {mo_unkline, 2}}
 };
 
 mapi_clist_av1 kline_clist[] = { &kline_msgtab, &unkline_msgtab, NULL };
 
-DECLARE_MODULE_AV1(kline, NULL, NULL, kline_clist, NULL, NULL, "$Revision$");
+DECLARE_MODULE_AV2(kline, NULL, NULL, kline_clist, NULL, NULL, NULL, NULL, kline_desc);
 
 /* Local function prototypes */
-static int find_user_host(struct Client *source_p, const char *userhost, char *user, char *host);
-static int valid_user_host(struct Client *source_p, const char *user, const char *host);
+static bool find_user_host(struct Client *source_p, const char *userhost, char *user, char *host);
+static bool valid_user_host(struct Client *source_p, const char *user, const char *host);
 
 static void handle_remote_kline(struct Client *source_p, int tkline_time,
 				const char *user, const char *host, const char *reason);
@@ -79,11 +78,11 @@ static void apply_tkline(struct Client *source_p, struct ConfItem *aconf,
 			 const char *, const char *, int);
 static void apply_prop_kline(struct Client *source_p, struct ConfItem *aconf,
 			 const char *, const char *, int);
-static int already_placed_kline(struct Client *, const char *, const char *, int);
+static bool already_placed_kline(struct Client *, const char *, const char *, int);
 
 static void handle_remote_unkline(struct Client *source_p, const char *user, const char *host);
 static void remove_permkline_match(struct Client *, struct ConfItem *);
-static int remove_temp_kline(struct Client *, struct ConfItem *);
+static bool remove_temp_kline(struct Client *, struct ConfItem *);
 static void remove_prop_kline(struct Client *, struct ConfItem *);
 
 /* mo_kline()
@@ -94,8 +93,8 @@ static void remove_prop_kline(struct Client *, struct ConfItem *);
  *   parv[4] - server to target, or reason
  *   parv[5] - reason
  */
-static int
-mo_kline(struct Client *client_p, struct Client *source_p, int parc, const char **parv)
+static void
+mo_kline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc, const char **parv)
 {
 	char def[] = "No Reason";
 	char user[USERLEN + 2];
@@ -106,12 +105,12 @@ mo_kline(struct Client *client_p, struct Client *source_p, int parc, const char
 	struct ConfItem *aconf;
 	int tkline_time = 0;
 	int loc = 1;
-	int propagated = ConfigFileEntry.use_propagated_bans;
+	bool propagated = ConfigFileEntry.use_propagated_bans;
 
 	if(!IsOperK(source_p))
 	{
 		sendto_one(source_p, form_str(ERR_NOPRIVS), me.name, source_p->name, "kline");
-		return 0;
+		return;
 	}
 
 	if((tkline_time = valid_temp_time(parv[loc])) >= 0)
@@ -121,7 +120,7 @@ mo_kline(struct Client *client_p, struct Client *source_p, int parc, const char
 		tkline_time = 0;
 
 	if(find_user_host(source_p, parv[loc], user, host) == 0)
-		return 0;
+		return;
 
 	loc++;
 
@@ -131,7 +130,7 @@ mo_kline(struct Client *client_p, struct Client *source_p, int parc, const char
 		{
 			sendto_one(source_p, form_str(ERR_NOPRIVS),
 				   me.name, source_p->name, "remoteban");
-			return 0;
+			return;
 		}
 
 		target_server = parv[loc + 1];
@@ -142,7 +141,7 @@ mo_kline(struct Client *client_p, struct Client *source_p, int parc, const char
 	{
 		sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS),
 			   me.name, source_p->name, "KLINE");
-		return 0;
+		return;
 	}
 
 	reason = LOCAL_COPY(parv[loc]);
@@ -154,10 +153,10 @@ mo_kline(struct Client *client_p, struct Client *source_p, int parc, const char
 
 		/* If we are sending it somewhere that doesnt include us, stop */
 		if(!match(target_server, me.name))
-			return 0;
+			return;
 
 		/* Set as local-only. */
-		propagated = 0;
+		propagated = false;
 	}
 	/* if we have cluster servers, send it to them.. */
 	else if(!propagated && rb_dlink_list_length(&cluster_conf_list) > 0)
@@ -166,7 +165,7 @@ mo_kline(struct Client *client_p, struct Client *source_p, int parc, const char
 				"%lu %s %s :%s", tkline_time, user, host, reason);
 
 	if(!valid_user_host(source_p, user, host))
-		return 0;
+		return;
 
 	if(!valid_wild_card(user, host))
 	{
@@ -174,17 +173,17 @@ mo_kline(struct Client *client_p, struct Client *source_p, int parc, const char
 				  ":Please include at least %d non-wildcard "
 				  "characters with the user@host",
 				  ConfigFileEntry.min_nonwildcard);
-		return 0;
+		return;
 	}
 
 	if(propagated && tkline_time == 0)
 	{
 		sendto_one_notice(source_p, ":Cannot set a permanent global ban");
-		return 0;
+		return;
 	}
 
 	if(already_placed_kline(source_p, user, host, tkline_time))
-		return 0;
+		return;
 
 	rb_set_time();
 	aconf = make_conf();
@@ -218,17 +217,15 @@ mo_kline(struct Client *client_p, struct Client *source_p, int parc, const char
 
 	if(ConfigFileEntry.kline_delay)
 	{
-		if(kline_queued == 0)
+		if(!kline_queued)
 		{
 			rb_event_addonce("check_klines", check_klines_event, NULL,
 					 ConfigFileEntry.kline_delay);
-			kline_queued = 1;
+			kline_queued = true;
 		}
 	}
 	else
 		check_klines();
-
-	return 0;
 }
 
 /* ms_kline()
@@ -239,8 +236,8 @@ mo_kline(struct Client *client_p, struct Client *source_p, int parc, const char
  *   parv[4] - host
  *   parv[5] - reason
  */
-static int
-ms_kline(struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
+static void
+ms_kline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
 {
 	int tkline_time = atoi(parv[2]);
 
@@ -249,30 +246,28 @@ ms_kline(struct Client *client_p, struct Client *source_p, int parc, const char
 	 * but its not worth dropping the link over.. --anfl
 	 */
 	if(parc < 6 || EmptyString(parv[5]))
-		return 0;
+		return;
 
 	propagate_generic(source_p, "KLINE", parv[1], CAP_KLN,
 			  "%d %s %s :%s", tkline_time, parv[3], parv[4], parv[5]);
 
 	if(!match(parv[1], me.name))
-		return 0;
+		return;
 
 	if(!IsPerson(source_p))
-		return 0;
+		return;
 
 	handle_remote_kline(source_p, tkline_time, parv[3], parv[4], parv[5]);
-	return 0;
 }
 
-static int
-me_kline(struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
+static void
+me_kline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
 {
 	/* <tkline_time> <user> <host> :<reason> */
 	if(!IsPerson(source_p))
-		return 0;
+		return;
 
 	handle_remote_kline(source_p, atoi(parv[1]), parv[2], parv[3], parv[4]);
-	return 0;
 }
 
 static void
@@ -332,17 +327,15 @@ handle_remote_kline(struct Client *source_p, int tkline_time,
 
 	if(ConfigFileEntry.kline_delay)
 	{
-		if(kline_queued == 0)
+		if(!kline_queued)
 		{
 			rb_event_addonce("check_klines", check_klines_event, NULL,
 					 ConfigFileEntry.kline_delay);
-			kline_queued = 1;
+			kline_queued = true;
 		}
 	}
 	else
 		check_klines();
-
-	return;
 }
 
 /* mo_unkline()
@@ -351,20 +344,20 @@ handle_remote_kline(struct Client *source_p, int tkline_time,
  *   parv[2] - optional "ON"
  *   parv[3] - optional target server
  */
-static int
-mo_unkline(struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
+static void
+mo_unkline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
 {
 	const char *user;
 	char *host;
 	char splat[] = "*";
 	char *h = LOCAL_COPY(parv[1]);
 	struct ConfItem *aconf;
-	int propagated = 1;
+	bool propagated = true;
 
 	if(!IsOperUnkline(source_p))
 	{
 		sendto_one(source_p, form_str(ERR_NOPRIVS), me.name, source_p->name, "unkline");
-		return 0;
+		return;
 	}
 
 	if((host = strchr(h, '@')) || *h == '*' || strchr(h, '.') || strchr(h, ':'))
@@ -394,7 +387,7 @@ mo_unkline(struct Client *client_p, struct Client *source_p, int parc, const cha
 	else
 	{
 		sendto_one_notice(source_p, ":Invalid parameters");
-		return 0;
+		return;
 	}
 
 	/* possible remote kline.. */
@@ -404,15 +397,15 @@ mo_unkline(struct Client *client_p, struct Client *source_p, int parc, const cha
 		{
 			sendto_one(source_p, form_str(ERR_NOPRIVS),
 				   me.name, source_p->name, "remoteban");
-			return 0;
+			return;
 		}
 
 		propagate_generic(source_p, "UNKLINE", parv[3], CAP_UNKLN, "%s %s", user, host);
 
 		if(match(parv[3], me.name) == 0)
-			return 0;
+			return;
 
-		propagated = 0;
+		propagated = false;
 	}
 
 	aconf = find_exact_conf_by_address(host, CONF_KILL, user);
@@ -426,7 +419,7 @@ mo_unkline(struct Client *client_p, struct Client *source_p, int parc, const cha
 	if(aconf == NULL)
 	{
 		sendto_one_notice(source_p, ":No K-Line for %s@%s", user, host);
-		return 0;
+		return;
 	}
 
 	if(aconf->lifetime)
@@ -435,15 +428,13 @@ mo_unkline(struct Client *client_p, struct Client *source_p, int parc, const cha
 			remove_prop_kline(source_p, aconf);
 		else
 			sendto_one_notice(source_p, ":Cannot remove global K-Line %s@%s on specific servers", user, host);
-		return 0;
+		return;
 	}
 
 	if(remove_temp_kline(source_p, aconf))
-		return 0;
+		return;
 
 	remove_permkline_match(source_p, aconf);
-
-	return 0;
 }
 
 /* ms_unkline()
@@ -452,32 +443,30 @@ mo_unkline(struct Client *client_p, struct Client *source_p, int parc, const cha
  *   parv[2] - user to unkline
  *   parv[3] - host to unkline
  */
-static int
-ms_unkline(struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
+static void
+ms_unkline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
 {
 	/* parv[0]  parv[1]        parv[2]  parv[3]
 	 * oper     target server  user     host    */
 	propagate_generic(source_p, "UNKLINE", parv[1], CAP_UNKLN, "%s %s", parv[2], parv[3]);
 
 	if(!match(parv[1], me.name))
-		return 0;
+		return;
 
 	if(!IsPerson(source_p))
-		return 0;
+		return;
 
 	handle_remote_unkline(source_p, parv[2], parv[3]);
-	return 0;
 }
 
-static int
-me_unkline(struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
+static void
+me_unkline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
 {
 	/* user host */
 	if(!IsPerson(source_p))
-		return 0;
+		return;
 
 	handle_remote_unkline(source_p, parv[1], parv[2]);
-	return 0;
 }
 
 static void
@@ -634,10 +623,10 @@ apply_prop_kline(struct Client *source_p, struct ConfItem *aconf,
 /* find_user_host()
  *
  * inputs	- client placing kline, user@host, user buffer, host buffer
- * output	- 0 if not ok to kline, 1 to kline i.e. if valid user host
+ * output	- false if not ok to kline, true to kline i.e. if valid user host
  * side effects -
  */
-static int
+static bool
 find_user_host(struct Client *source_p, const char *userhost, char *luser, char *lhost)
 {
 	char *hostp;
@@ -664,7 +653,7 @@ find_user_host(struct Client *source_p, const char *userhost, char *luser, char
 		if(strchr(userhost, '.') == NULL && strchr(userhost, ':') == NULL)
 		{
 			sendto_one_notice(source_p, ":K-Line must be a user@host or host");
-			return 0;
+			return false;
 		}
 
 		luser[0] = '*';	/* no @ found, assume its *@somehost */
@@ -676,43 +665,43 @@ find_user_host(struct Client *source_p, const char *userhost, char *luser, char
 	if (*luser == ':' || *lhost == ':')
 	{
 		sendto_one_notice(source_p, ":Invalid K-Line");
-		return 0;
+		return false;
 	}
 
-	return 1;
+	return true;
 }
 
 /* valid_user_host()
  *
  * inputs       - user buffer, host buffer
- * output	- 0 if invalid, 1 if valid
+ * output	- false if invalid, true if valid
  * side effects -
  */
-static int
+static bool
 valid_user_host(struct Client *source_p, const char *luser, const char *lhost)
 {
 	/* # is invalid, as are '!' (n!u@h kline) and '@' (u@@h kline) */
 	if(strchr(lhost, '#') || strchr(luser, '#') || strchr(luser, '!') || strchr(lhost, '@'))
 	{
 		sendto_one_notice(source_p, ":Invalid K-Line");
-		return 0;
+		return false;
 	}
 
-	return 1;
+	return true;
 }
 
 /* already_placed_kline()
  *
  * inputs       - source to notify, user@host to check, tkline time
- * outputs      - 1 if a perm kline or a tkline when a tkline is being
- *                set exists, else 0
+ * outputs      - true if a perm kline or a tkline when a tkline is being
+ *                set exists, else false
  * side effects - notifies source_p kline exists
  */
 /* Note: This currently works if the new K-line is a special case of an
  *       existing K-line, but not the other way round. To do that we would
  *       have to walk the hash and check every existing K-line. -A1kmm.
  */
-static int
+static bool
 already_placed_kline(struct Client *source_p, const char *luser, const char *lhost, int tkline)
 {
 	const char *reason, *p;
@@ -726,11 +715,9 @@ already_placed_kline(struct Client *source_p, const char *luser, const char *lho
 		bits = 0;
 		if((t = parse_netmask(lhost, &iphost, &bits)) != HM_HOST)
 		{
-#ifdef RB_IPV6
 			if(t == HM_IPV6)
 				t = AF_INET6;
 			else
-#endif
 				t = AF_INET;
 
 			piphost = &iphost;
@@ -762,11 +749,11 @@ already_placed_kline(struct Client *source_p, const char *luser, const char *lho
 			sendto_one_notice(source_p,
 					  ":[%s@%s] already K-Lined by [%s@%s] - %s",
 					  luser, lhost, aconf->user, aconf->host, reason);
-			return 1;
+			return true;
 		}
 	}
 
-	return 0;
+	return false;
 }
 
 /* remove_permkline_match()
@@ -787,8 +774,6 @@ remove_permkline_match(struct Client *source_p, struct ConfItem *aconf)
 	remove_reject_mask(aconf->user, aconf->host);
 	bandb_del(BANDB_KLINE, aconf->user, aconf->host);
 	delete_one_address_conf(aconf->host, aconf);
-
-	return;
 }
 
 /* remove_temp_kline()
@@ -797,7 +782,7 @@ remove_permkline_match(struct Client *source_p, struct ConfItem *aconf)
  * outputs      -
  * side effects - tries to unkline anything that matches
  */
-static int
+static bool
 remove_temp_kline(struct Client *source_p, struct ConfItem *aconf)
 {
 	rb_dlink_node *ptr;
@@ -822,12 +807,12 @@ remove_temp_kline(struct Client *source_p, struct ConfItem *aconf)
 				rb_dlinkDestroy(ptr, &temp_klines[i]);
 				remove_reject_mask(aconf->user, aconf->host);
 				delete_one_address_conf(aconf->host, aconf);
-				return YES;
+				return true;
 			}
 		}
 	}
 
-	return NO;
+	return false;
 }
 
 static void
