@@ -20,8 +20,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
- *
- *  $Id: m_post.c 498 2006-01-15 16:40:33Z jilles $
  */
 
 #include "stdinc.h"
@@ -35,36 +33,36 @@
 #include "modules.h"
 #include "s_conf.h"
 
-static int mr_dumb_proxy(struct Client *, struct Client *, int, const char **);
+static const char post_desc[] =
+	"Ensure Web forms/proxies cannot connect by disconnecting on POST, GET, and PUT";
+
+static void mr_dumb_proxy(struct MsgBuf *, struct Client *, struct Client *, int, const char **);
 
 struct Message post_msgtab = {
-	"POST", 0, 0, 0, MFLG_SLOW | MFLG_UNREG,
+	"POST", 0, 0, 0, 0,
 	{{mr_dumb_proxy, 0}, mg_ignore, mg_ignore, mg_ignore, mg_ignore, mg_ignore}
 };
 struct Message get_msgtab = {
-	"GET", 0, 0, 0, MFLG_SLOW | MFLG_UNREG,
+	"GET", 0, 0, 0, 0,
 	{{mr_dumb_proxy, 0}, mg_ignore, mg_ignore, mg_ignore, mg_ignore, mg_ignore}
 };
 struct Message put_msgtab = {
-	"PUT", 0, 0, 0, MFLG_SLOW | MFLG_UNREG,
+	"PUT", 0, 0, 0, 0,
 	{{mr_dumb_proxy, 0}, mg_ignore, mg_ignore, mg_ignore, mg_ignore, mg_ignore}
 };
 
-
 mapi_clist_av1 post_clist[] = {
 	&post_msgtab, &get_msgtab, &put_msgtab, NULL
 };
-DECLARE_MODULE_AV1(post, NULL, NULL, post_clist, NULL, NULL, "$Revision: 498 $");
 
+DECLARE_MODULE_AV2(post, NULL, NULL, post_clist, NULL, NULL, NULL, NULL, post_desc);
 
 /*
 ** mr_dumb_proxy
 **      parv[1] = comment
 */
-static int
-mr_dumb_proxy(struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
+static void
+mr_dumb_proxy(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
 {
 	exit_client(client_p, source_p, source_p, "Client Exit");
-
-	return 0;
 }
