@@ -1,5 +1,5 @@
 /* modules/m_xline.c
- * 
+ *
  *  Copyright (C) 2002-2003 Lee Hardy <lee@leeh.co.uk>
  *  Copyright (C) 2002-2005 ircd-ratbox development team
  *
@@ -26,16 +26,13 @@
  * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
  * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
- *
- * $Id$
  */
 
 #include "stdinc.h"
 #include "send.h"
 #include "channel.h"
 #include "client.h"
-#include "common.h"
-#include "config.h"
+#include "defaults.h"
 #include "class.h"
 #include "ircd.h"
 #include "numeric.h"
@@ -53,33 +50,22 @@
 #include "bandbi.h"
 #include "operhash.h"
 
-static int mo_xline(struct Client *client_p, struct Client *source_p, int parc, const char *parv[]);
-static int ms_xline(struct Client *client_p, struct Client *source_p, int parc, const char *parv[]);
-static int me_xline(struct Client *client_p, struct Client *source_p, int parc, const char *parv[]);
-static int mo_unxline(struct Client *client_p, struct Client *source_p, int parc,
+static const char xline_desc[] =
+	"Provides management of GECOS bans via (UN)XLINE command";
+
+static void mo_xline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc, const char *parv[]);
+static void ms_xline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc, const char *parv[]);
+static void me_xline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc, const char *parv[]);
+static void mo_unxline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc,
 		      const char *parv[]);
-static int ms_unxline(struct Client *client_p, struct Client *source_p, int parc,
+static void ms_unxline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc,
 		      const char *parv[]);
-static int me_unxline(struct Client *client_p, struct Client *source_p, int parc,
+static void me_unxline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc,
 		      const char *parv[]);
 
-struct Message xline_msgtab = {
-	"XLINE", 0, 0, 0, MFLG_SLOW,
-	{mg_unreg, mg_not_oper, {ms_xline, 5}, {ms_xline, 5}, {me_xline, 5}, {mo_xline, 3}}
-};
-
-struct Message unxline_msgtab = {
-	"UNXLINE", 0, 0, 0, MFLG_SLOW,
-	{mg_unreg, mg_not_oper, {ms_unxline, 3}, {ms_unxline, 3}, {me_unxline, 2}, {mo_unxline, 2}}
-};
-
-mapi_clist_av1 xline_clist[] = { &xline_msgtab, &unxline_msgtab, NULL };
-
-DECLARE_MODULE_AV1(xline, NULL, NULL, xline_clist, NULL, NULL, "$Revision$");
-
-static int valid_xline(struct Client *, const char *, const char *);
+static bool valid_xline(struct Client *, const char *, const char *);
 static void apply_xline(struct Client *client_p, const char *name,
-			const char *reason, int temp_time, int propagated);
+			const char *reason, int temp_time, bool propagated);
 static void propagate_xline(struct Client *source_p, const char *target,
 			    int temp_time, const char *name, const char *type, const char *reason);
 static void cluster_xline(struct Client *source_p, int temp_time,
@@ -88,10 +74,22 @@ static void cluster_xline(struct Client *source_p, int temp_time,
 static void handle_remote_xline(struct Client *source_p, int temp_time,
 				const char *name, const char *reason);
 static void handle_remote_unxline(struct Client *source_p, const char *name);
-
 static void remove_xline(struct Client *source_p, const char *name,
-			 int propagated);
+			 bool propagated);
 
+struct Message xline_msgtab = {
+	"XLINE", 0, 0, 0, 0,
+	{mg_unreg, mg_not_oper, {ms_xline, 5}, {ms_xline, 5}, {me_xline, 5}, {mo_xline, 3}}
+};
+
+struct Message unxline_msgtab = {
+	"UNXLINE", 0, 0, 0, 0,
+	{mg_unreg, mg_not_oper, {ms_unxline, 3}, {ms_unxline, 3}, {me_unxline, 2}, {mo_unxline, 2}}
+};
+
+mapi_clist_av1 xline_clist[] = { &xline_msgtab, &unxline_msgtab, NULL };
+
+DECLARE_MODULE_AV2(xline, NULL, NULL, xline_clist, NULL, NULL, NULL, NULL, xline_desc);
 
 /* m_xline()
  *
@@ -99,8 +97,8 @@ static void remove_xline(struct Client *source_p, const char *name,
  * parv[2] - optional type/reason
  * parv[3] - reason
  */
-static int
-mo_xline(struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
+static void
+mo_xline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
 {
 	struct ConfItem *aconf;
 	const char *name;
@@ -108,12 +106,12 @@ mo_xline(struct Client *client_p, struct Client *source_p, int parc, const char
 	const char *target_server = NULL;
 	int temp_time;
 	int loc = 1;
-	int propagated = ConfigFileEntry.use_propagated_bans;
+	bool propagated = ConfigFileEntry.use_propagated_bans;
 
 	if(!IsOperXline(source_p))
 	{
 		sendto_one(source_p, form_str(ERR_NOPRIVS), me.name, source_p->name, "xline");
-		return 0;
+		return;
 	}
 
 	if((temp_time = valid_temp_time(parv[loc])) >= 0)
@@ -132,7 +130,7 @@ mo_xline(struct Client *client_p, struct Client *source_p, int parc, const char
 		{
 			sendto_one(source_p, form_str(ERR_NOPRIVS),
 				   me.name, source_p->name, "remoteban");
-			return 0;
+			return;
 		}
 
 		target_server = parv[loc + 1];
@@ -143,7 +141,7 @@ mo_xline(struct Client *client_p, struct Client *source_p, int parc, const char
 	{
 		sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS),
 			   me.name, source_p->name, "XLINE");
-		return 0;
+		return;
 	}
 
 	reason = parv[loc];
@@ -153,10 +151,10 @@ mo_xline(struct Client *client_p, struct Client *source_p, int parc, const char
 		propagate_xline(source_p, target_server, temp_time, name, "2", reason);
 
 		if(!match(target_server, me.name))
-			return 0;
+			return;
 
 		/* Set as local-only. */
-		propagated = 0;
+		propagated = false;
 	}
 	else if(!propagated && rb_dlink_list_length(&cluster_conf_list) > 0)
 		cluster_xline(source_p, temp_time, name, reason);
@@ -165,29 +163,27 @@ mo_xline(struct Client *client_p, struct Client *source_p, int parc, const char
 	{
 		sendto_one(source_p, ":%s NOTICE %s :[%s] already X-Lined by [%s] - %s",
 			   me.name, source_p->name, name, aconf->host, aconf->passwd);
-		return 0;
+		return;
 	}
 
 	if(!valid_xline(source_p, name, reason))
-		return 0;
+		return;
 
 	if(propagated && temp_time == 0)
 	{
 		sendto_one_notice(source_p, ":Cannot set a permanent global ban");
-		return 0;
+		return;
 	}
 
 	apply_xline(source_p, name, reason, temp_time, propagated);
-
-	return 0;
 }
 
 /* ms_xline()
  *
  * handles a remote xline
  */
-static int
-ms_xline(struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
+static void
+ms_xline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
 {
 	/* parv[0]  parv[1]      parv[2]  parv[3]  parv[4]
 	 * oper     target serv  xline    type     reason
@@ -195,25 +191,23 @@ ms_xline(struct Client *client_p, struct Client *source_p, int parc, const char
 	propagate_xline(source_p, parv[1], 0, parv[2], parv[3], parv[4]);
 
 	if(!IsPerson(source_p))
-		return 0;
+		return;
 
 	/* destined for me? */
 	if(!match(parv[1], me.name))
-		return 0;
+		return;
 
 	handle_remote_xline(source_p, 0, parv[2], parv[4]);
-	return 0;
 }
 
-static int
-me_xline(struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
+static void
+me_xline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
 {
 	/* time name type :reason */
 	if(!IsPerson(source_p))
-		return 0;
+		return;
 
 	handle_remote_xline(source_p, atoi(parv[1]), parv[2], parv[4]);
-	return 0;
 }
 
 static void
@@ -237,7 +231,7 @@ handle_remote_xline(struct Client *source_p, int temp_time, const char *name, co
 		return;
 	}
 
-	apply_xline(source_p, name, reason, temp_time, 0);
+	apply_xline(source_p, name, reason, temp_time, false);
 }
 
 /* valid_xline()
@@ -246,14 +240,14 @@ handle_remote_xline(struct Client *source_p, int temp_time, const char *name, co
  * outputs	-
  * side effects - checks the xline for validity, erroring if needed
  */
-static int
+static bool
 valid_xline(struct Client *source_p, const char *gecos, const char *reason)
 {
 	if(EmptyString(reason))
 	{
 		sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS),
 			   get_id(&me, source_p), get_id(source_p, source_p), "XLINE");
-		return 0;
+		return false;
 	}
 
 	if(!valid_wild_card_simple(gecos))
@@ -262,14 +256,14 @@ valid_xline(struct Client *source_p, const char *gecos, const char *reason)
 				  ":Please include at least %d non-wildcard "
 				  "characters with the xline",
 				  ConfigFileEntry.min_nonwildcard_simple);
-		return 0;
+		return false;
 	}
 
-	return 1;
+	return true;
 }
 
 void
-apply_xline(struct Client *source_p, const char *name, const char *reason, int temp_time, int propagated)
+apply_xline(struct Client *source_p, const char *name, const char *reason, int temp_time, bool propagated)
 {
 	struct ConfItem *aconf;
 
@@ -387,15 +381,15 @@ cluster_xline(struct Client *source_p, int temp_time, const char *name, const ch
  *
  * parv[1] - thing to unxline
  */
-static int
-mo_unxline(struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
+static void
+mo_unxline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
 {
-	int propagated = 1;
+	bool propagated = true;
 
 	if(!IsOperXline(source_p))
 	{
 		sendto_one(source_p, form_str(ERR_NOPRIVS), me.name, source_p->name, "xline");
-		return 0;
+		return;
 	}
 
 	if(parc == 4 && !(irccmp(parv[2], "ON")))
@@ -404,29 +398,27 @@ mo_unxline(struct Client *client_p, struct Client *source_p, int parc, const cha
 		{
 			sendto_one(source_p, form_str(ERR_NOPRIVS),
 				   me.name, source_p->name, "remoteban");
-			return 0;
+			return;
 		}
 
 		propagate_generic(source_p, "UNXLINE", parv[3], CAP_CLUSTER, "%s", parv[1]);
 
 		if(match(parv[3], me.name) == 0)
-			return 0;
+			return;
 
-		propagated = 0;
+		propagated = false;
 	}
 	/* cluster{} moved to remove_xline */
 
 	remove_xline(source_p, parv[1], propagated);
-
-	return 0;
 }
 
 /* ms_unxline()
  *
  * handles a remote unxline
  */
-static int
-ms_unxline(struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
+static void
+ms_unxline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
 {
 	/* parv[0]  parv[1]        parv[2]
 	 * oper     target server  gecos
@@ -434,24 +426,22 @@ ms_unxline(struct Client *client_p, struct Client *source_p, int parc, const cha
 	propagate_generic(source_p, "UNXLINE", parv[1], CAP_CLUSTER, "%s", parv[2]);
 
 	if(!match(parv[1], me.name))
-		return 0;
+		return;
 
 	if(!IsPerson(source_p))
-		return 0;
+		return;
 
 	handle_remote_unxline(source_p, parv[2]);
-	return 0;
 }
 
-static int
-me_unxline(struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
+static void
+me_unxline(struct MsgBuf *msgbuf_p, struct Client *client_p, struct Client *source_p, int parc, const char *parv[])
 {
 	/* name */
 	if(!IsPerson(source_p))
-		return 0;
+		return;
 
 	handle_remote_unxline(source_p, parv[1]);
-	return 0;
 }
 
 static void
@@ -461,16 +451,15 @@ handle_remote_unxline(struct Client *source_p, const char *name)
 			     source_p->servptr->name, SHARED_UNXLINE))
 		return;
 
-	remove_xline(source_p, name, 0);
-
-	return;
+	remove_xline(source_p, name, false);
 }
 
 static void
-remove_xline(struct Client *source_p, const char *name, int propagated)
+remove_xline(struct Client *source_p, const char *name, bool propagated)
 {
 	struct ConfItem *aconf;
 	rb_dlink_node *ptr;
+	time_t now;
 
 	RB_DLINK_FOREACH(ptr, xline_conf_list.head)
 	{
@@ -493,8 +482,9 @@ remove_xline(struct Client *source_p, const char *name, int propagated)
 						       "%s has removed the global X-Line for: [%s]",
 						       get_oper_name(source_p), name);
 				ilog(L_KLINE, "UX %s %s", get_oper_name(source_p), name);
-				if(aconf->created < rb_current_time())
-					aconf->created = rb_current_time();
+				now = rb_current_time();
+				if(aconf->created < now)
+					aconf->created = now;
 				else
 					aconf->created++;
 				aconf->hold = aconf->created;
@@ -508,7 +498,7 @@ remove_xline(struct Client *source_p, const char *name, int propagated)
 						0,
 						(int)(aconf->lifetime - aconf->created));
 				remove_reject_mask(aconf->host, NULL);
-				deactivate_conf(aconf, ptr);
+				deactivate_conf(aconf, ptr, now);
 				return;
 			}
 			else if(propagated && rb_dlink_list_length(&cluster_conf_list))
@@ -543,6 +533,4 @@ remove_xline(struct Client *source_p, const char *name, int propagated)
 		cluster_generic(source_p, "UNXLINE", SHARED_UNXLINE, CAP_CLUSTER, "%s", name);
 
 	sendto_one_notice(source_p, ":No X-Line for %s", name);
-
-	return;
 }
